==> haskell-nonce-1.0.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-nonce/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.2
id: nonce-1.0.2-ba2a4fc59a4ebf1fc9363b2dcb9c988b
key: nonce_KLRCtSXnFprAb9ehhs84xC
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
exposed-modules:
    Crypto.Nonce
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/nonce-1.0.2
hs-libraries: HSnonce-1.0.2-KLRCtSXnFprAb9ehhs84xC
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cprng-aes-0.6.1-4f88e976d4e99640259c02d6940382c2
    crypto-random-0.0.9-1a34631cfa2fcb67c67a6201143b0147
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nonce-1.0.2-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-nonce/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.2
id: nonce-1.0.2-c0bfd19efc8c42e1c2c83d3a058f813a
key: nonce_Aq8Gw0TPkT5H9Hiky2rRh6
license: BSD3
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
exposed: True
exposed-modules:
    Crypto.Nonce
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/nonce-1.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/nonce-1.0.2
hs-libraries: HSnonce-1.0.2-Aq8Gw0TPkT5H9Hiky2rRh6
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cprng-aes-0.6.1-4f88e976d4e99640259c02d6940382c2
    crypto-random-0.0.9-1a34631cfa2fcb67c67a6201143b0147
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
